'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-5d7ef74f.js');
const index$2 = require('./index-ce9a1d00.js');
const index$1 = require('./index-5a88e57b.js');
const dataTestIds_enum = require('./dataTestIds.enum-f00213b8.js');
const getIconHtmlFromIconDefinition = require('./getIconHtmlFromIconDefinition-07bb4d7b.js');

const isWindowAvailable = () => typeof window != 'undefined' && typeof (window === null || window === void 0 ? void 0 : window.location) != 'undefined';

function fallbackCopyTextToClipboard(text) {
    let success = false;
    if (!document || !document.body) {
        console.error('Document or document.body is not available');
        return success;
    }
    const textArea = document.createElement('textarea');
    textArea.value = text;
    textArea.style.position = 'fixed';
    textArea.style.left = '-9999px';
    textArea.style.top = '0';
    document.body.appendChild(textArea);
    try {
        textArea.focus();
        textArea.setSelectionRange(0, textArea.value.length);
        success = document.execCommand('copy');
    }
    catch (err) {
        console.error('Fallback: Oops, unable to copy', err);
    }
    finally {
        document.body.removeChild(textArea);
    }
    return success;
}
async function copyToClipboard(text) {
    if (!isWindowAvailable()) {
        return false;
    }
    let success = false;
    if (!navigator.clipboard) {
        success = fallbackCopyTextToClipboard(text);
    }
    else {
        success = await navigator.clipboard.writeText(text).then(function done() {
            return true;
        }, function error(err) {
            console.error('Async: Could not copy text: ', err);
            return false;
        });
    }
    return success;
}

const copyButtonCss = ".copy-button{color:#6c757d}";
const CopyButtonStyle0 = copyButtonCss;

const CopyButton = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.isSuccess = false;
        this.handleClick = async (event) => {
            event.preventDefault();
            event.stopPropagation();
            const trimmedText = this.text ? this.text.trim() : this.text;
            const success = await copyToClipboard(trimmedText);
            this.isSuccess = success;
            if (success) {
                this.timeoutId = window.setTimeout(() => {
                    this.isSuccess = false;
                }, 1000);
            }
        };
    }
    disconnectedCallback() {
        // Clear the timeout if the component is unmounted
        if (this.timeoutId) {
            clearTimeout(this.timeoutId);
            this.timeoutId = undefined; // Reset the timeout ID
        }
    }
    render() {
        var _a, _b;
        const copyIcon = (_a = this.copyIcon) !== null && _a !== void 0 ? _a : index$2.faCopy;
        const successIcon = (_b = this.successIcon) !== null && _b !== void 0 ? _b : index$2.faCheck;
        return (index.h("a", { key: '91c879db1913e5cdf70dbe9d62426985b2b7e2af', href: "/#", class: index$1.classNames(this.class, 'copy-button'), onClick: this.handleClick }, index.h("fa-icon", { key: 'e34d43755d71682daee40628fd48ed2c0fbfe6f0', icon: this.isSuccess ? successIcon : copyIcon })));
    }
};
CopyButton.style = CopyButtonStyle0;

const transactionToastDetailsBodyCss = ".transaction-container {\n  line-height: 1.5;\n  font-size: 0.875rem;\n  padding-right: 0.5rem;\n  display: flex;\n  align-items: center;\n  margin-bottom: 0.2rem;\n  justify-content: space-between;\n  --explorer-link-color: #6c757d;\n\n  .actions {\n    display: flex;\n    align-items: center;\n    gap: 0.75rem;\n  }\n\n  .icon {\n    svg {\n      font-size: 0.875rem;\n      color: #6c757d;\n      margin-right: 0.25rem;\n      width: 1rem;\n    }\n  }\n\n  .fa-spin {\n    svg {\n      animation: spin 2s linear infinite;\n    }\n  }\n\n  .trim {\n    width: 11rem;\n    white-space: nowrap;\n    margin-right: 1rem;\n  }\n}\n\n@keyframes spin {\n  0% {\n    transform: rotate(0deg);\n  }\n  100% {\n    transform: rotate(360deg);\n  }\n}";
const TransactionToastDetailsBodyStyle0 = transactionToastDetailsBodyCss;

const iconData = {
    pending: index$2.faCircleNotch,
    success: index$2.faCheck,
    fail: index$2.faTimes,
    invalid: index$2.faTimes,
};
const TransactionDetailsBody = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.transactionClass = 'transaction-container';
    }
    render() {
        const statusIcon = this.status ? iconData[this.status] : null;
        const iconHtml = statusIcon ? getIconHtmlFromIconDefinition.getIconHtmlFromIconDefinition(statusIcon) : null;
        return (index.h("div", { class: this.transactionClass, key: this.hash, "data-testid": dataTestIds_enum.DataTestIdsEnum.transactionDetailsToastBody }, iconHtml && (index.h("div", { key: 'b31a9d98c9c2e66dd46ab4975a85e5d301fdcd3f', innerHTML: iconHtml, class: index$1.classNames('icon', {
                'fa-spin': this.status === 'pending',
            }) })), index.h("span", { key: 'cc37f827e6a361b0f57ba57a4fd57d2983e6d3ed', class: "trim" }, index.h("trim-text", { key: 'c92ebde9d334563ce4543f7901eb552c5b0ef6a2', text: this.hash })), index.h("div", { key: 'c7dabc89abbeae4794ead247d0397750cb01a28a', class: "actions" }, index.h("copy-button", { key: '7d46e7f8fd1275a7f25c09dd50c269838ecd8b20', text: this.hash }), index.h("explorer-link", { key: '9c5a035045fb21adac3add20b517ca42046473f9', link: this.link }))));
    }
};
TransactionDetailsBody.style = TransactionToastDetailsBodyStyle0;

exports.copy_button = CopyButton;
exports.transaction_toast_details_body = TransactionDetailsBody;

//# sourceMappingURL=copy-button_2.cjs.entry.js.map