'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-5d7ef74f.js');
const dataTestIds_enum = require('./dataTestIds.enum-f00213b8.js');

function trimAddress(s) {
    const firstFour = s.slice(0, 6);
    const lastFour = s.slice(-6);
    return `${firstFour}...${lastFour}`;
}
const renderAccounts = ({ shownAccounts = [], onSelectAccount, selectedIndex }) => {
    return (index.h("div", { class: "account-list", "data-testid": dataTestIds_enum.DataTestIdsEnum.addressTableContainer },
        index.h("div", { class: "account-header" },
            index.h("div", { class: "account-header-item" }, "Address"),
            index.h("div", { class: "account-header-item" }, "Balance"),
            index.h("div", { class: "account-header-item" }, "#")),
        shownAccounts.map(account => (index.h("div", { class: "account-row", onClick: () => onSelectAccount(account.index) },
            index.h("div", { class: "address-row-item-data " },
                index.h("input", { type: "radio", name: "account", checked: account.index === selectedIndex, value: account.index }),
                index.h("span", { class: "address" }, trimAddress(account.address))),
            index.h("div", { class: "address-row-item-data" }, account.balance),
            index.h("div", { class: "address-row-item-data" }, account.index))))));
};

const ledgerAccountScreenCss = ".account-header{display:flex;align-items:center;background-color:#ced4da;line-height:1;padding:16px;text-align:left;font-size:14px;border-radius:8px;padding-right:20px}.account-header-item{flex:1}.account-header-item:first-child{width:55%;max-width:55%}.account-header-item:last-child{width:32px;max-width:32px;flex-basis:32px;text-align:center}.account-list{width:100%;min-height:300px;max-height:300px;position:relative;overflow:auto}.account-row{display:flex;align-items:center;padding:16px;border-radius:8px;cursor:pointer}.account-row:hover{background-color:#f5f5f5}.address-row-item-data{font-size:14px;line-height:1;flex:1;text-align:left;display:flex;align-items:center;padding-right:16px}.address-row-item-data:last-child{width:32px;max-width:32px;flex-basis:32px;text-align:center;justify-content:center;padding-right:0}.navigation{display:flex;justify-content:center;gap:10rem;margin-top:20px}.navigation-button{background:transparent;border:none;cursor:pointer}.navigation-button:hover{color:#1a56db}.navigation-button:disabled{color:#737373;pointer-events:none}.access-button{display:block;width:200px;margin:20px auto;padding:12px;background-color:#1a56db;color:white;border:none;border-radius:8px;cursor:pointer}.access-button:disabled{background-color:#a1a1a1;color:#e0e0e0;cursor:not-allowed;opacity:0.6;box-shadow:none;transform:none}";
const LedgerAccountScreenStyle0 = ledgerAccountScreenCss;

const LedgerAccountScreen = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.selectAccount = index.createEvent(this, "selectAccount", 7);
        this.nextPage = index.createEvent(this, "nextPage", 7);
        this.prevPage = index.createEvent(this, "prevPage", 7);
        this.accessWallet = index.createEvent(this, "accessWallet", 7);
    }
    render() {
        const isSelectedIndexOnPage = this.accountScreenData.accounts.some(({ index }) => index === this.selectedIndex);
        const accountsList = this.accountScreenData.isLoading || this.accountScreenData.accounts.length === 0 ? (index.h("generic-spinner", { "data-testid": dataTestIds_enum.DataTestIdsEnum.ledgerLoading })) : (renderAccounts({
            shownAccounts: this.accountScreenData.accounts,
            onSelectAccount: (index) => this.selectAccount.emit(index),
            selectedIndex: this.selectedIndex,
        }));
        return (index.h(index.Fragment, { key: '838d37d86d04247b19101ff5dc387a6531c90265' }, accountsList, !this.accountScreenData.isLoading && this.accountScreenData.accounts.length !== 0 && (index.h(index.Fragment, { key: 'aeb62e0519bbcc46944ce97bcace57504db3f73b' }, index.h("div", { key: 'c4bd512b2c8b08591774abc0af92a85e16697c85', class: "navigation" }, index.h("button", { key: '0c891e5f8af57d75a693f4cf9a12d2114aa493cb', onClick: () => this.prevPage.emit(), disabled: this.accountScreenData.startIndex <= 0, "data-testid": dataTestIds_enum.DataTestIdsEnum.prevBtn, class: "navigation-button" }, '< ', " Prev"), index.h("button", { key: '081d4f65b0c978dc2be6700631d41ae4eadfc1ac', onClick: () => this.nextPage.emit(), "data-testid": dataTestIds_enum.DataTestIdsEnum.nextBtn, class: "navigation-button" }, "Next", ' >')), index.h("button", { key: 'ef36f5928ee6c5a4e90661edffaf41718f35326e', "data-testid": dataTestIds_enum.DataTestIdsEnum.confirmBtn, class: "access-button", onClick: () => this.accessWallet.emit(), disabled: !isSelectedIndexOnPage }, "Access Wallet")))));
    }
};
LedgerAccountScreen.style = LedgerAccountScreenStyle0;

const ledgerConfirmScreenCss = ".address-section{line-height:1.5;margin-top:40px;font-size:16px;text-align:center}.address-section .address-description{color:#858688}.address-section .address-data{background-color:#ced4da;line-height:1;padding:12px;text-align:center;border-radius:8px;word-break:break-word}.address-section .address-header{background-color:#ced4da;line-height:1;padding:12px;text-align:center;border-radius:8px}.address-footer{font-size:14px;color:var(--gray-700);line-height:1.5;position:relative;margin-top:40px;padding-top:40px}.address-footer::before{height:1px;content:\"\";left:0;bottom:100%;right:0;position:absolute;background-color:var(--gray-700)}.address-footer a{color:var(--primary)}";
const LedgerConfirmScreenStyle0 = ledgerConfirmScreenCss;

const LedgerConnectConfirmBody = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
    }
    render() {
        var _a, _b, _c;
        return (index.h("div", { key: '0880892711fbeb784c21e15496b4173565280af6', "data-testid": dataTestIds_enum.DataTestIdsEnum.ledgerConfirmAddress, class: "address-section" }, index.h("div", { key: '706e6edcc03110f2497b17e38e0e11fc60ad892c', class: "address-section" }, index.h("div", { key: '7da51c02c52439bfef22334ef622b8704eab39ec', class: "address-description" }, this.confirmScreenData.confirmAddressText), index.h("div", { key: '925967ec6e7737d9f1caa98959fc76d41962a832', class: "address-header" }, this.confirmScreenData.selectedAddress)), index.h("div", { key: 'e2e8d8db7bcbfa7e1b60447b24bbb5fca5ec1680', class: "address-section" }, index.h("div", { key: '121b66e3ec8229c535c73da6cf3b637fc438abff', class: "address-description" }, (_a = this.confirmScreenData) === null || _a === void 0 ? void 0 : _a.authText), index.h("div", { key: '5c0e247e7a1e336a8542476dd37584aeafd4cb5e', class: "address-data" }, (_b = this.confirmScreenData) === null || _b === void 0 ? void 0 : _b.data), index.h("div", { key: '68b203c6f68d96afa4e28dab583650c539344269', class: "address-description" }, (_c = this.confirmScreenData) === null || _c === void 0 ? void 0 : _c.areShownText)), index.h("div", { key: '35dbb8d7dbe719b3e401b28472c6ee7eebee8217', class: "address-footer" }, index.h("div", { key: '4299c9327bd3e334e4a72e79fe6694632f4115a4' }, "Select Approve on your device to confirm."), index.h("div", { key: '2cbc978bc0f591b5819c3518f6c7c645e2814e67' }, "Or, if it does not match, close this page and", ' ', index.h("a", { key: '5ce66e477655b258e75f07a857b10939a6b1702e', href: "https://help.multiversx.com/en/", target: "_blank", rel: "noreferrer" }, "contact support"), "."))));
    }
};
LedgerConnectConfirmBody.style = LedgerConfirmScreenStyle0;

const ledgerConnectScreenCss = ".access-button{display:block;width:200px;margin:20px auto;padding:12px;background-color:#1a56db;color:white;border:none;border-radius:8px;cursor:pointer}.access-button:disabled{background-color:#a1a1a1;color:#e0e0e0;cursor:not-allowed;opacity:0.6;box-shadow:none;transform:none}.connection-link{display:flex;justify-content:center}";
const LedgerConnectScreenStyle0 = ledgerConnectScreenCss;

const LedgerConnectScreen = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.connect = index.createEvent(this, "connect", 7);
    }
    render() {
        var _a, _b, _c, _d;
        return (index.h("div", { key: '08fe03416fca00f63a2e653589ec45c8972cc5c9' }, ((_a = this.connectScreenData) === null || _a === void 0 ? void 0 : _a.error) && index.h("p", { key: '5eaa4d2a23f19ebe7ce71aa2e691dba9dffe2182' }, this.connectScreenData.error), ((_b = this.connectScreenData) === null || _b === void 0 ? void 0 : _b.customContentMarkup) && ((_c = this.connectScreenData) === null || _c === void 0 ? void 0 : _c.customContentMarkup), index.h("button", { key: '4fca2ae10bd0fb94e9c1036ce074e6d3fb4c0c7e', "data-testid": dataTestIds_enum.DataTestIdsEnum.ledgerConnectBtn, class: "access-button", onClick: () => this.connect.emit(), disabled: (_d = this.connectScreenData) === null || _d === void 0 ? void 0 : _d.disabled }, "Connect Ledger"), index.h("a", { key: 'fdf5f3204413be7230985f4b229e8fc21cdc57ca', href: "https://support.ledger.com/hc/en-us/articles/115005165269-Connection-issues-with-Windows-or-Linux", target: "_blank", rel: "noopener noreferrer", class: "connection-link" }, "Having connection issues?")));
    }
};
LedgerConnectScreen.style = LedgerConnectScreenStyle0;

exports.ledger_account_screen = LedgerAccountScreen;
exports.ledger_confirm_screen = LedgerConnectConfirmBody;
exports.ledger_connect_screen = LedgerConnectScreen;

//# sourceMappingURL=ledger-account-screen_3.cjs.entry.js.map