'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-5d7ef74f.js');
const dataTestIds_enum = require('./dataTestIds.enum-f00213b8.js');
const utils = require('./utils-ea4b6a17.js');
const signTransactionsModalStore = require('./signTransactionsModalStore-57f24a0e.js');

const signTransactionComponentCss = "* {\n  margin: 0;\n  padding: 0;\n  box-sizing: border-box;\n}\n\n.transaction-container {\n  display: flex;\n  flex-direction: column;\n  padding: 0rem 1rem 0rem 1rem;\n  gap: 1rem;\n}\n\n.receiver-container {\n  display: flex;\n  flex-direction: column;\n  align-items: flex-start;\n  gap: 4px;\n  line-height: 1;\n}\n\n.data-container {\n  display: flex;\n  flex-direction: column;\n  align-items: flex-start;\n  gap: 4px;\n  line-height: 1;\n}\n\n.data-content-container {\n  display: block;\n  width: 100%;\n  min-height: 100px;\n  height: 100px;\n  border: 1px solid #ccc;\n  border-radius: 4px;\n  padding: 8px;\n  overflow-y: auto;\n  font-family: inherit;\n  font-size: inherit;\n  background-color: #f9f9f9;\n  white-space: pre-wrap;\n  word-wrap: break-word;\n  color: #333;\n}\n\n.data-content {\n  opacity: 0.6;\n}\n\n.fee-container {\n  display: flex;\n  flex-direction: column;\n  align-items: flex-start;\n  gap: 4px;\n  line-height: 1;\n}\n\n.sign-button-container {\n  display: flex;\n  flex-direction: column;\n}\n\n.sign-back-button {\n  display: inline-block;\n  padding: 8px 12px;\n  background-color: transparent;\n  color: #1a56db;\n  border: none;\n  border-radius: 4px;\n  cursor: pointer;\n  text-decoration: none;\n  font-size: 16px;\n\n  &:hover {\n    text-decoration: underline;\n    color: #0033a0;\n  }\n\n  &:active {\n    color: #001f70;\n  }\n\n  &:disabled {\n    color: #a1a1a1;\n    cursor: not-allowed;\n    text-decoration: none;\n    opacity: 0.6;\n  }\n}\n\n.sign-button {\n  display: block;\n  width: 200px;\n  margin: 0 auto;\n  padding: 12px;\n  background-color: #1a56db;\n  color: white;\n  border: none;\n  border-radius: 8px;\n  cursor: pointer;\n\n  &:disabled {\n    background-color: #a1a1a1;\n    color: #e0e0e0;\n    cursor: not-allowed;\n    opacity: 0.6;\n    box-shadow: none;\n    transform: none;\n  }\n}\n\n.highlight {\n  opacity: 1;\n}\n";
const SignTransactionComponentStyle0 = signTransactionComponentCss;

var __rest = (undefined && undefined.__rest) || function (s, e) {
    var t = {};
    for (var p in s)
        if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
            t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
const SignTransaction = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
    }
    getSignButtonProps() {
        const { currentIndex, nextUnsignedTxIndex } = signTransactionsModalStore.state.commonData;
        if (currentIndex === nextUnsignedTxIndex) {
            return {
                signText: 'Sign',
                disabled: signTransactionsModalStore.state.isWaitingForSignature,
                'data-testid': dataTestIds_enum.DataTestIdsEnum.signTransactionBtn,
                onClick: signTransactionsModalStore.state.onSign
            };
        }
        return {
            signText: 'Next',
            disabled: false,
            'data-testid': dataTestIds_enum.DataTestIdsEnum.signNextTransactionBtn,
            onClick: signTransactionsModalStore.state.onNext
        };
    }
    getBackButtonProps() {
        const { transactionsCount, currentIndex } = signTransactionsModalStore.state.commonData;
        const isMultipleTransactions = transactionsCount > 1;
        if (!isMultipleTransactions) {
            return {};
        }
        if (currentIndex === 0) {
            return {
                'data-testid': dataTestIds_enum.DataTestIdsEnum.signCancelBtn,
                backButtonText: 'Cancel',
                onClick: signTransactionsModalStore.state.onCancel
            };
        }
        return {
            'data-testid': dataTestIds_enum.DataTestIdsEnum.signBackBtn,
            backButtonText: 'Back',
            onClick: signTransactionsModalStore.state.onPrev,
            disabled: signTransactionsModalStore.state.isWaitingForSignature
        };
    }
    getHighlightedData() {
        const { data, highlight } = signTransactionsModalStore.state.commonData;
        if (!highlight || !data) {
            return data;
        }
        const parts = data.split(highlight);
        return (index.h("span", null, parts.map((part, index$1) => (index.h("span", null, index.h("span", { class: "data-content" }, part), index$1 < parts.length - 1 && (index.h("span", { class: "highlight" }, highlight)))))));
    }
    render() {
        const { receiver, egldLabel, feeInFiatLimit, feeLimit, scCall } = signTransactionsModalStore.state.commonData;
        const _a = this.getSignButtonProps(), { signText } = _a, signButtonProps = __rest(_a, ["signText"]);
        const _b = this.getBackButtonProps(), { backButtonText } = _b, backButtonProps = __rest(_b, ["backButtonText"]);
        const highlightedData = this.getHighlightedData();
        return (index.h("div", { key: 'bf5bf14d8407e108d714bc2a9e318963b64f2bd7', class: "transaction-container" }, this.header, index.h("div", { key: 'acde433bfd8e4c4f0a4a01f551ae748dc8611b13', class: "receiver-container" }, index.h("p", { key: '382f1806e2ce31310c8783d18e6717992354ad73' }, "To"), index.h("p", { key: 'fe61ab719a98dbe6c2e5b8251c0a713670c15d00' }, utils.formatAddress(receiver, 40))), index.h("div", { key: '145c4390356bf3a2a07a00f87eee645a1426a463', class: "fee-container" }, index.h("p", { key: '3c702c9398dd0f48d9eb3323da835458a9f78f6d' }, "Transaction fee"), feeLimit && (index.h("p", { key: '056d6017c661df7cea5a43592986faa7dd6c180f' }, index.h("span", { key: '604d34f0bc5213e5edc259e8817597da12f9138a' }, feeLimit), "\u00A0", index.h("span", { key: '1e284511dcc4f40ee618dd06d0f81fd9a6bcc15e' }, egldLabel))), index.h("p", { key: '20e762571a45fd2b8e98cf13844344c70b86a19f' }, "\u2248", feeInFiatLimit)), scCall && (index.h("div", { key: '7385b2d15641e3c9a4f5501e83a54751d6cf6066', class: "data-container" }, index.h("p", { key: 'adaff7539de2d467b73465bf03587b672ee45844' }, "Smart Contract Call"), index.h("div", { key: 'a662d70f29ccb6d73cb26fc2994e5a26e9b2c9d9', class: "data-content-container" }, scCall))), index.h("div", { key: 'e37168b085fce93386672a20c471418a03af665e', class: "data-container" }, index.h("p", { key: 'c8689bf03766dffbffcf24813a0eba5096303747' }, "Data"), index.h("div", { key: '314483b4408080f681bff5775c5080b609aecc2f', class: "data-content-container" }, highlightedData)), index.h("div", { key: '000a1e9990f6b5cf4e5ca66e30e406c660071dfb', class: "sign-button-container" }, index.h("button", Object.assign({ key: '4fd7334d5d939616521394fcf86399b276afb4c0', class: "sign-button" }, signButtonProps), signText), backButtonText && (index.h("button", Object.assign({ key: '9039aa3e66f1e06f180679943137867652015b12', class: "sign-back-button" }, backButtonProps), backButtonText)))));
    }
};
SignTransaction.style = SignTransactionComponentStyle0;

exports.sign_transaction_component = SignTransaction;

//# sourceMappingURL=sign-transaction-component.cjs.entry.js.map