var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s)
        if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
            t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { h } from "@stencil/core";
import { DataTestIdsEnum } from "../../../../../constants/dataTestIds.enum";
import { formatAddress } from "../../../../../utils/utils";
import state from "../../signTransactionsModalStore";
export class SignTransaction {
    getSignButtonProps() {
        const { currentIndex, nextUnsignedTxIndex } = state.commonData;
        if (currentIndex === nextUnsignedTxIndex) {
            return {
                signText: 'Sign',
                disabled: state.isWaitingForSignature,
                'data-testid': DataTestIdsEnum.signTransactionBtn,
                onClick: state.onSign
            };
        }
        return {
            signText: 'Next',
            disabled: false,
            'data-testid': DataTestIdsEnum.signNextTransactionBtn,
            onClick: state.onNext
        };
    }
    getBackButtonProps() {
        const { transactionsCount, currentIndex } = state.commonData;
        const isMultipleTransactions = transactionsCount > 1;
        if (!isMultipleTransactions) {
            return {};
        }
        if (currentIndex === 0) {
            return {
                'data-testid': DataTestIdsEnum.signCancelBtn,
                backButtonText: 'Cancel',
                onClick: state.onCancel
            };
        }
        return {
            'data-testid': DataTestIdsEnum.signBackBtn,
            backButtonText: 'Back',
            onClick: state.onPrev,
            disabled: state.isWaitingForSignature
        };
    }
    getHighlightedData() {
        const { data, highlight } = state.commonData;
        if (!highlight || !data) {
            return data;
        }
        const parts = data.split(highlight);
        return (h("span", null, parts.map((part, index) => (h("span", null, h("span", { class: "data-content" }, part), index < parts.length - 1 && (h("span", { class: "highlight" }, highlight)))))));
    }
    render() {
        const { receiver, egldLabel, feeInFiatLimit, feeLimit, scCall } = state.commonData;
        const _a = this.getSignButtonProps(), { signText } = _a, signButtonProps = __rest(_a, ["signText"]);
        const _b = this.getBackButtonProps(), { backButtonText } = _b, backButtonProps = __rest(_b, ["backButtonText"]);
        const highlightedData = this.getHighlightedData();
        return (h("div", { key: 'bf5bf14d8407e108d714bc2a9e318963b64f2bd7', class: "transaction-container" }, this.header, h("div", { key: 'acde433bfd8e4c4f0a4a01f551ae748dc8611b13', class: "receiver-container" }, h("p", { key: '382f1806e2ce31310c8783d18e6717992354ad73' }, "To"), h("p", { key: 'fe61ab719a98dbe6c2e5b8251c0a713670c15d00' }, formatAddress(receiver, 40))), h("div", { key: '145c4390356bf3a2a07a00f87eee645a1426a463', class: "fee-container" }, h("p", { key: '3c702c9398dd0f48d9eb3323da835458a9f78f6d' }, "Transaction fee"), feeLimit && (h("p", { key: '056d6017c661df7cea5a43592986faa7dd6c180f' }, h("span", { key: '604d34f0bc5213e5edc259e8817597da12f9138a' }, feeLimit), "\u00A0", h("span", { key: '1e284511dcc4f40ee618dd06d0f81fd9a6bcc15e' }, egldLabel))), h("p", { key: '20e762571a45fd2b8e98cf13844344c70b86a19f' }, "\u2248", feeInFiatLimit)), scCall && (h("div", { key: '7385b2d15641e3c9a4f5501e83a54751d6cf6066', class: "data-container" }, h("p", { key: 'adaff7539de2d467b73465bf03587b672ee45844' }, "Smart Contract Call"), h("div", { key: 'a662d70f29ccb6d73cb26fc2994e5a26e9b2c9d9', class: "data-content-container" }, scCall))), h("div", { key: 'e37168b085fce93386672a20c471418a03af665e', class: "data-container" }, h("p", { key: 'c8689bf03766dffbffcf24813a0eba5096303747' }, "Data"), h("div", { key: '314483b4408080f681bff5775c5080b609aecc2f', class: "data-content-container" }, highlightedData)), h("div", { key: '000a1e9990f6b5cf4e5ca66e30e406c660071dfb', class: "sign-button-container" }, h("button", Object.assign({ key: '4fd7334d5d939616521394fcf86399b276afb4c0', class: "sign-button" }, signButtonProps), signText), backButtonText && (h("button", Object.assign({ key: '9039aa3e66f1e06f180679943137867652015b12', class: "sign-back-button" }, backButtonProps), backButtonText)))));
    }
    static get is() { return "sign-transaction-component"; }
    static get originalStyleUrls() {
        return {
            "$": ["sign-transaction-component.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["sign-transaction-component.css"]
        };
    }
    static get properties() {
        return {
            "header": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "VNode",
                    "resolved": "VNode",
                    "references": {
                        "VNode": {
                            "location": "import",
                            "path": "@stencil/core",
                            "id": "node_modules::VNode"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            }
        };
    }
}
//# sourceMappingURL=sign-transaction-component.js.map
