import { Fragment, h } from "@stencil/core";
import classNames from "classnames";
const DEFAULT_INFINITE_ANIMATION_DURATION = 30;
export class ToastProgress {
    constructor() {
        this.currentTimestamp = Date.now() / 1000;
        this.hasTimeElapsed = false;
        this.expectedTransactionDuration = 0;
        this.secondsPassedSinceStart = 0;
        this.shouldShowProgressBar = false;
        this.percentagePassedSinceStart = 0;
        this.shouldQuickFill = false;
        this.infiniteProgressDelay = 0;
        this.infinitePercentagePassedSinceStart = 0;
        this.infinitePercentageAnimationDuration = DEFAULT_INFINITE_ANIMATION_DURATION + (this.endTime - this.startTime) * 2;
    }
    componentWillLoad() {
        this.updateProgress();
    }
    handleTimeChange() {
        this.updateProgress();
    }
    updateProgress() {
        this.shouldShowProgressBar = Boolean(this.endTime) && Boolean(this.startTime);
        if (!this.shouldShowProgressBar) {
            this.shouldQuickFill = true;
            this.timeElapsedTimeoutReference = setTimeout(() => (this.hasTimeElapsed = true), 500);
            return;
        }
        this.currentTimestamp = Date.now() / 1000;
        this.expectedTransactionDuration = this.endTime - this.startTime;
        this.secondsPassedSinceStart = this.currentTimestamp - this.startTime;
        this.percentagePassedSinceStart = this.expectedTransactionDuration > 0 ? (this.secondsPassedSinceStart / this.expectedTransactionDuration) * 100 : 0;
        this.infiniteProgressDelay = Math.max(0, this.expectedTransactionDuration - this.secondsPassedSinceStart);
        this.infinitePercentagePassedSinceStart = (this.secondsPassedSinceStart / (this.expectedTransactionDuration + this.infinitePercentageAnimationDuration)) * 100;
    }
    disconnectedCallback() {
        if (this.timeElapsedTimeoutReference) {
            clearTimeout(this.timeElapsedTimeoutReference);
        }
    }
    render() {
        return (h(Fragment, { key: '17d20c3cba450c3246390ec7e4bacac31c14faae' }, h("div", { key: '186afef6a363bd4442423433ef3657a549d8f357', class: "transaction-toast-bar-wrapper", style: { opacity: this.hasTimeElapsed ? '0' : '1' } }, h("div", { key: 'f7839f7d30162bbe6bff080a7161f84d68e5765a', class: "transaction-toast-bar fixed", style: {
                '--animation-duration': `${this.expectedTransactionDuration}s`,
                '--start-width': `${this.percentagePassedSinceStart}%`,
            } }), h("div", { key: 'b3225a264857691d58bfea7f1802dba0f21e629d', class: "transaction-toast-bar infinite" }, h("div", { key: 'd971423bb5c54f62603709cc85d237b9d3386dd3', class: "transaction-toast-bar-line", style: {
                '--start-width': `${this.infinitePercentagePassedSinceStart}%`,
                '--animation-duration': `${this.infinitePercentageAnimationDuration}s`,
                '--animation-delay': `${this.infiniteProgressDelay}s`,
            } })), h("div", { key: 'dd33a3ec7ae7bea03a3d1826d6e4fb9074b8fff7', class: classNames('transaction-toast-bar fill', {
                animate: this.shouldQuickFill,
            }) })), h("div", { key: '0dfa097e7d6439bfaaef2e0893e2755453b1420c', class: "transaction-toast-bar-content" }, h("slot", { key: '63b18f4ce255a84011421f6b76293b3cc459e19f' }))));
    }
    static get is() { return "transaction-toast-progress"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["transaction-toast-progress.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["transaction-toast-progress.css"]
        };
    }
    static get properties() {
        return {
            "startTime": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "start-time",
                "reflect": false
            },
            "endTime": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "end-time",
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "currentTimestamp": {},
            "hasTimeElapsed": {},
            "expectedTransactionDuration": {},
            "secondsPassedSinceStart": {},
            "shouldShowProgressBar": {},
            "percentagePassedSinceStart": {},
            "shouldQuickFill": {},
            "infiniteProgressDelay": {},
            "infinitePercentagePassedSinceStart": {},
            "infinitePercentageAnimationDuration": {}
        };
    }
    static get watchers() {
        return [{
                "propName": "startTime",
                "methodName": "handleTimeChange"
            }, {
                "propName": "endTime",
                "methodName": "handleTimeChange"
            }];
    }
}
//# sourceMappingURL=transaction-toast-progress.js.map
