import { forceUpdate, h } from "@stencil/core";
import { EventBus } from "../../../utils/EventBus";
import { ToastEventsEnum } from "./toast-list.types";
export class ToastList {
    constructor() {
        this.eventBus = new EventBus();
    }
    async getEventBus() {
        return this.eventBus;
    }
    handleCustomToastDelete(toastId) {
        this.eventBus.publish(ToastEventsEnum.CLOSE_TOAST, toastId);
    }
    handleTransactionToastDelete(toastId) {
        this.eventBus.publish(ToastEventsEnum.CLOSE_TOAST, toastId);
    }
    render() {
        var _a, _b;
        return (h("div", { key: '65e3f2066ac2d53d9070fd491ac2909a0e9fe5f0', class: "toast-list", id: "toast-list" }, (_a = this.customToasts) === null || _a === void 0 ? void 0 :
            _a.map(toast => h("generic-toast", { toast: toast, onHandleDeleteToast: this.handleCustomToastDelete.bind(this, toast.toastId) })), (_b = this.transactionToasts) === null || _b === void 0 ? void 0 :
            _b.map(toast => h("transaction-toast", Object.assign({}, toast, { onHandleDeleteToast: this.handleTransactionToastDelete.bind(this, toast.toastId) })))));
    }
    transactionToastUpdate(payload) {
        this.transactionToasts = [...payload];
        forceUpdate(this);
    }
    customToastsUpdate(payload) {
        this.customToasts = [...payload];
        forceUpdate(this);
    }
    componentDidLoad() {
        this.eventBus.subscribe(ToastEventsEnum.TRANSACTION_TOAST_DATA_UPDATE, this.transactionToastUpdate.bind(this));
        this.eventBus.subscribe(ToastEventsEnum.CUSTOM_TOAST_DATA_UPDATE, this.customToastsUpdate.bind(this));
    }
    static get is() { return "toast-list"; }
    static get originalStyleUrls() {
        return {
            "$": ["toast-list.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["toast-list.css"]
        };
    }
    static get properties() {
        return {
            "transactionToasts": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "ITransactionToast[]",
                    "resolved": "ITransactionToast[]",
                    "references": {
                        "ITransactionToast": {
                            "location": "import",
                            "path": "./components/transaction-toast/transaction-toast.type",
                            "id": "src/components/functional/toasts-list/components/transaction-toast/transaction-toast.type.ts::ITransactionToast"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            },
            "customToasts": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "CustomToastType[]",
                    "resolved": "CustomToastType[]",
                    "references": {
                        "CustomToastType": {
                            "location": "import",
                            "path": "./components/transaction-toast/transaction-toast.type",
                            "id": "src/components/functional/toasts-list/components/transaction-toast/transaction-toast.type.ts::CustomToastType"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            }
        };
    }
    static get methods() {
        return {
            "getEventBus": {
                "complexType": {
                    "signature": "() => Promise<IEventBus>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "IEventBus": {
                            "location": "import",
                            "path": "utils/EventBus",
                            "id": "src/utils/EventBus.ts::IEventBus"
                        }
                    },
                    "return": "Promise<IEventBus>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
}
//# sourceMappingURL=toast-list.js.map
