import { faArrowLeft } from "@fortawesome/free-solid-svg-icons";
import { h } from "@stencil/core";
import { ProviderTypeEnum } from "../../types/provider.types";
export class UnlockPanel {
    constructor() {
        this.open = false;
        this.allowedProviders = Object.values(ProviderTypeEnum);
        this.isVisible = false; // Controls DOM presence
        this.shouldAnimate = false; // Ensures animation plays on open
        this.isLoggingIn = false;
        this.selectedMethod = null;
        this.anchor = null;
        this.observer = null;
        this.closeTimeout = null;
        this.handleClose = (event) => {
            if (event.target === event.currentTarget) {
                this.close.emit();
            }
        };
        this.handleLogin = (provider) => {
            this.login.emit({ provider, anchor: this.anchor });
            this.selectedMethod = provider;
        };
        this.resetLoginState = () => {
            this.isLoggingIn = false;
            this.selectedMethod = null;
            if (!this.anchor) {
                return;
            }
            while (this.anchor.firstChild) {
                this.anchor.removeChild(this.anchor.firstChild);
            }
        };
    }
    handleOpenChange(newValue) {
        if (newValue) {
            if (this.closeTimeout) {
                clearTimeout(this.closeTimeout);
            }
            this.isVisible = true; // Ensure component is in DOM
            // Delay animation to allow rendering first
            return requestAnimationFrame(() => {
                this.shouldAnimate = true;
            });
        }
        this.shouldAnimate = false;
        this.closeTimeout = setTimeout(() => {
            this.isVisible = false;
            this.resetLoginState();
        }, 300); // Delay unmounting after animation
    }
    disconnectedCallback() {
        if (this.closeTimeout) {
            clearTimeout(this.closeTimeout);
        }
        if (this.observer) {
            this.observer.disconnect();
        }
    }
    observeContainer(element) {
        if (!element) {
            return;
        }
        this.anchor = element;
        if (this.observer) {
            this.observer.disconnect();
        }
        this.observer = new MutationObserver(() => {
            this.isLoggingIn = element.childElementCount > 0;
        });
        this.observer.observe(element, { childList: true, subtree: true });
    }
    render() {
        if (!this.isVisible) {
            return null;
        }
        return (h("div", { class: {
                overlay: true,
                visible: this.shouldAnimate,
                hidden: !this.shouldAnimate,
            }, onClick: this.handleClose, tabindex: "-1" }, h("div", { class: "panel" }, h("unlock-header", { text: this.isLoggingIn ? `${this.selectedMethod} connect` : 'Connect your wallet', backIcon: this.isLoggingIn ? faArrowLeft : null, onBack: this.resetLoginState, onClose: () => this.close.emit() }), h("div", { id: "anchor", ref: element => this.observeContainer(element) }), !this.isLoggingIn && (h("div", { class: "body" }, this.allowedProviders.map(method => (h("provider-button", { type: method, onClick: () => this.handleLogin(method) }))), h("slot", null))))));
    }
    static get is() { return "unlock-panel"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["unlock-panel.scss"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["unlock-panel.css"]
        };
    }
    static get properties() {
        return {
            "open": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "open",
                "reflect": false,
                "defaultValue": "false"
            },
            "allowedProviders": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "ProviderTypeEnum[]",
                    "resolved": "ProviderTypeEnum[]",
                    "references": {
                        "ProviderTypeEnum": {
                            "location": "import",
                            "path": "types/provider.types",
                            "id": "src/types/provider.types.ts::ProviderTypeEnum"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "defaultValue": "Object.values(ProviderTypeEnum)"
            }
        };
    }
    static get states() {
        return {
            "isVisible": {},
            "shouldAnimate": {},
            "isLoggingIn": {},
            "selectedMethod": {}
        };
    }
    static get events() {
        return [{
                "method": "close",
                "name": "close",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }, {
                "method": "login",
                "name": "login",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "{ provider: ProviderTypeEnum; anchor?: HTMLElement }",
                    "resolved": "{ provider: ProviderTypeEnum; anchor?: HTMLElement; }",
                    "references": {
                        "ProviderTypeEnum": {
                            "location": "import",
                            "path": "types/provider.types",
                            "id": "src/types/provider.types.ts::ProviderTypeEnum"
                        },
                        "HTMLElement": {
                            "location": "global",
                            "id": "global::HTMLElement"
                        }
                    }
                }
            }];
    }
    static get watchers() {
        return [{
                "propName": "open",
                "methodName": "handleOpenChange"
            }];
    }
}
//# sourceMappingURL=unlock-panel.js.map
