import { p as proxyCustomElement, H, h, f as forceUpdate } from './p-8a2c7dab.js';
import { L as LedgerConnectBase, a as LedgerConnectEventsEnum } from './p-0d9caba2.js';
import { d as defineCustomElement$5 } from './p-8324d312.js';
import { d as defineCustomElement$4 } from './p-a08bd3bc.js';
import { d as defineCustomElement$3 } from './p-9358f0f5.js';
import { d as defineCustomElement$2 } from './p-23e9fe20.js';

const LedgerConnect$1 = /*@__PURE__*/ proxyCustomElement(class LedgerConnect extends H {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.data = {
            accountScreenData: null,
            confirmScreenData: null,
            connectScreenData: {},
        };
        this.selectedIndex = 0;
    }
    componentWillLoad() {
        this.ledgerConnectBase = new LedgerConnectBase(this.data);
    }
    async getEventBus() {
        return this.ledgerConnectBase.getEventBus();
    }
    render() {
        const { accountScreenData, confirmScreenData, connectScreenData } = this.data;
        if (accountScreenData) {
            return (h("ledger-account-screen", { accountScreenData: accountScreenData, selectedIndex: this.selectedIndex, onSelectAccount: (event) => this.selectAccount(event.detail), onAccessWallet: () => this.accessWallet(), onPrevPage: () => this.prevPage(), onNextPage: () => this.nextPage() }));
        }
        if (confirmScreenData) {
            return h("ledger-confirm-screen", { confirmScreenData: confirmScreenData });
        }
        return h("ledger-connect-screen", { connectScreenData: connectScreenData, onConnect: () => this.ledgerConnectBase.eventBus.publish(LedgerConnectEventsEnum.CONNECT_DEVICE) });
    }
    accessWallet() {
        this.ledgerConnectBase.accessWallet();
    }
    selectAccount(index) {
        this.ledgerConnectBase.selectAccount(index);
        // this is needed for the UI to be reactive
        this.selectedIndex = this.ledgerConnectBase.selectedIndex;
    }
    async nextPage() {
        this.ledgerConnectBase.nextPage();
    }
    async prevPage() {
        this.ledgerConnectBase.prevPage();
    }
    removeComponent() {
        var _a;
        if ((_a = this.hostElement) === null || _a === void 0 ? void 0 : _a.parentNode) {
            this.hostElement.parentNode.removeChild(this.hostElement);
        }
    }
    componentDidLoad() {
        this.ledgerConnectBase.subscribeEventBus({
            closeFn: () => this.removeComponent(),
            forceUpdateFn: () => {
                // this is needed for the UI to be reactive
                this.data = this.ledgerConnectBase.data;
                forceUpdate(this);
            },
        });
    }
    disconnectedCallback() {
        this.ledgerConnectBase.unsubscribeEventBus({
            closeFn: () => this.removeComponent(),
            forceUpdateFn: () => {
                // this is needed for the UI to be reactive
                this.data = this.ledgerConnectBase.data;
                forceUpdate(this);
            },
        });
    }
    get hostElement() { return this; }
}, [1, "ledger-connect", {
        "data": [16],
        "selectedIndex": [32],
        "getEventBus": [64]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["ledger-connect", "generic-spinner", "ledger-account-screen", "ledger-confirm-screen", "ledger-connect-screen"];
    components.forEach(tagName => { switch (tagName) {
        case "ledger-connect":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, LedgerConnect$1);
            }
            break;
        case "generic-spinner":
            if (!customElements.get(tagName)) {
                defineCustomElement$5();
            }
            break;
        case "ledger-account-screen":
            if (!customElements.get(tagName)) {
                defineCustomElement$4();
            }
            break;
        case "ledger-confirm-screen":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "ledger-connect-screen":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}

const LedgerConnect = LedgerConnect$1;
const defineCustomElement = defineCustomElement$1;

export { LedgerConnect, defineCustomElement };

//# sourceMappingURL=ledger-connect.js.map