import { p as proxyCustomElement, H, h, F as Fragment } from './p-8a2c7dab.js';
import { c as classNames } from './p-12360e4c.js';

const transactionToastProgressCss = "@keyframes progressiveFixedWidthExpansion{from{width:min(var(--start-width, 0%), 80%)}to{width:80%}}@keyframes progressiveInfiniteWidthExpansion{from{width:min(var(--start-width, 0%), 100%)}to{width:100%}}@keyframes quickWidthExpansion{from{width:0%}to{width:100%}}.transaction-toast-progress{position:relative}.transaction-toast-bar-wrapper{transition:opacity 250ms ease-in;background-color:lightgray;position:absolute;pointer-events:none;left:0;top:0;opacity:25%;bottom:0;right:0;display:flex;overflow:hidden;border-radius:0.25rem;flex-direction:row-reverse}.transaction-toast-bar{height:100%;right:0;top:0;bottom:0}.transaction-toast-bar.fixed{width:min(var(--start-width, 0%), 50%);background-color:white;animation-name:progressiveFixedWidthExpansion;animation-duration:var(--animation-duration, 6s);animation-timing-function:cubic-bezier(0.5, 0.95, 0, 0.35);animation-fill-mode:forwards}.transaction-toast-bar.infinite{width:20%;display:flex;flex-direction:row-reverse}.transaction-toast-bar.infinite .transaction-toast-bar-line{width:0%;background-color:white;animation-name:progressiveInfiniteWidthExpansion;animation-duration:var(--animation-duration, 60s);animation-timing-function:cubic-bezier(0.1, 0.95, 0.25, 0.75);animation-fill-mode:forwards;animation-delay:var(--animation-delay, 6s);height:100%;position:relative}.transaction-toast-bar.infinite .transaction-toast-bar-line:before{position:absolute;background-color:white;content:'';width:calc(4px / 2);right:-1px;top:0;bottom:0}.transaction-toast-bar.fill{width:0%;position:absolute;background-color:white}.transaction-toast-bar.fill.animate{animation:quickWidthExpansion 250ms linear forwards}.transaction-toast-bar-content{z-index:1;position:relative}";
const TransactionToastProgressStyle0 = transactionToastProgressCss;

const DEFAULT_INFINITE_ANIMATION_DURATION = 30;
const ToastProgress = /*@__PURE__*/ proxyCustomElement(class ToastProgress extends H {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.currentTimestamp = Date.now() / 1000;
        this.hasTimeElapsed = false;
        this.expectedTransactionDuration = 0;
        this.secondsPassedSinceStart = 0;
        this.shouldShowProgressBar = false;
        this.percentagePassedSinceStart = 0;
        this.shouldQuickFill = false;
        this.infiniteProgressDelay = 0;
        this.infinitePercentagePassedSinceStart = 0;
        this.infinitePercentageAnimationDuration = DEFAULT_INFINITE_ANIMATION_DURATION + (this.endTime - this.startTime) * 2;
    }
    componentWillLoad() {
        this.updateProgress();
    }
    handleTimeChange() {
        this.updateProgress();
    }
    updateProgress() {
        this.shouldShowProgressBar = Boolean(this.endTime) && Boolean(this.startTime);
        if (!this.shouldShowProgressBar) {
            this.shouldQuickFill = true;
            this.timeElapsedTimeoutReference = setTimeout(() => (this.hasTimeElapsed = true), 500);
            return;
        }
        this.currentTimestamp = Date.now() / 1000;
        this.expectedTransactionDuration = this.endTime - this.startTime;
        this.secondsPassedSinceStart = this.currentTimestamp - this.startTime;
        this.percentagePassedSinceStart = this.expectedTransactionDuration > 0 ? (this.secondsPassedSinceStart / this.expectedTransactionDuration) * 100 : 0;
        this.infiniteProgressDelay = Math.max(0, this.expectedTransactionDuration - this.secondsPassedSinceStart);
        this.infinitePercentagePassedSinceStart = (this.secondsPassedSinceStart / (this.expectedTransactionDuration + this.infinitePercentageAnimationDuration)) * 100;
    }
    disconnectedCallback() {
        if (this.timeElapsedTimeoutReference) {
            clearTimeout(this.timeElapsedTimeoutReference);
        }
    }
    render() {
        return (h(Fragment, { key: '17d20c3cba450c3246390ec7e4bacac31c14faae' }, h("div", { key: '186afef6a363bd4442423433ef3657a549d8f357', class: "transaction-toast-bar-wrapper", style: { opacity: this.hasTimeElapsed ? '0' : '1' } }, h("div", { key: 'f7839f7d30162bbe6bff080a7161f84d68e5765a', class: "transaction-toast-bar fixed", style: {
                '--animation-duration': `${this.expectedTransactionDuration}s`,
                '--start-width': `${this.percentagePassedSinceStart}%`,
            } }), h("div", { key: 'b3225a264857691d58bfea7f1802dba0f21e629d', class: "transaction-toast-bar infinite" }, h("div", { key: 'd971423bb5c54f62603709cc85d237b9d3386dd3', class: "transaction-toast-bar-line", style: {
                '--start-width': `${this.infinitePercentagePassedSinceStart}%`,
                '--animation-duration': `${this.infinitePercentageAnimationDuration}s`,
                '--animation-delay': `${this.infiniteProgressDelay}s`,
            } })), h("div", { key: 'dd33a3ec7ae7bea03a3d1826d6e4fb9074b8fff7', class: classNames('transaction-toast-bar fill', {
                animate: this.shouldQuickFill,
            }) })), h("div", { key: '0dfa097e7d6439bfaaef2e0893e2755453b1420c', class: "transaction-toast-bar-content" }, h("slot", { key: '63b18f4ce255a84011421f6b76293b3cc459e19f' }))));
    }
    static get watchers() { return {
        "startTime": ["handleTimeChange"],
        "endTime": ["handleTimeChange"]
    }; }
    static get style() { return TransactionToastProgressStyle0; }
}, [1, "transaction-toast-progress", {
        "startTime": [2, "start-time"],
        "endTime": [2, "end-time"],
        "currentTimestamp": [32],
        "hasTimeElapsed": [32],
        "expectedTransactionDuration": [32],
        "secondsPassedSinceStart": [32],
        "shouldShowProgressBar": [32],
        "percentagePassedSinceStart": [32],
        "shouldQuickFill": [32],
        "infiniteProgressDelay": [32],
        "infinitePercentagePassedSinceStart": [32],
        "infinitePercentageAnimationDuration": [32]
    }, undefined, {
        "startTime": ["handleTimeChange"],
        "endTime": ["handleTimeChange"]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["transaction-toast-progress"];
    components.forEach(tagName => { switch (tagName) {
        case "transaction-toast-progress":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, ToastProgress);
            }
            break;
    } });
}

export { ToastProgress as T, defineCustomElement as d };

//# sourceMappingURL=p-3c110c7e.js.map