import { h, F as Fragment, p as proxyCustomElement, H } from './p-8a2c7dab.js';
import { d as defineCustomElement$1 } from './p-9793e2eb.js';

// types here need to be synced with the types in sdk-dapp-core providerFactory.types.ts
var ProviderTypeEnum;
(function (ProviderTypeEnum) {
    ProviderTypeEnum["crossWindow"] = "crossWindow";
    ProviderTypeEnum["extension"] = "extension";
    ProviderTypeEnum["walletConnect"] = "walletConnect";
    ProviderTypeEnum["ledger"] = "ledger";
    ProviderTypeEnum["metamask"] = "metamask";
    ProviderTypeEnum["passkey"] = "passkey";
})(ProviderTypeEnum || (ProviderTypeEnum = {}));

const providerButtonCss = ":host{display:block;width:100%}.connect-button{display:flex;align-items:center;padding:12px;border-radius:12px;background:white;box-shadow:0 2px 6px rgba(0, 0, 0, 0.05);cursor:pointer;transition:background 0.3s ease}.connect-button:hover{background:#fafafa}.connect-icon{width:40px;height:40px;border-radius:8px;overflow:hidden;display:flex;align-items:center;justify-content:center;border:1px solid #ebe5df}.connect-icon img{width:100%;height:100%;object-fit:cover}.connect-label{flex:1;margin-left:12px;font-size:16px;font-weight:500}";
const ProviderButtonStyle0 = providerButtonCss;

const providerButtonInfo = {
    [ProviderTypeEnum.extension]: {
        icon: h(Fragment, null),
        label: 'MultiversX Wallet Extension',
    },
    [ProviderTypeEnum.metamask]: {
        icon: h(Fragment, null),
        label: 'Metamask Snap',
    },
    [ProviderTypeEnum.passkey]: {
        icon: h(Fragment, null),
        label: 'Passkey',
    },
    [ProviderTypeEnum.walletConnect]: {
        icon: h(Fragment, null),
        label: 'xPortal Wallet',
    },
    [ProviderTypeEnum.ledger]: {
        icon: h(Fragment, null),
        label: 'Ledger',
    },
    [ProviderTypeEnum.crossWindow]: {
        icon: h(Fragment, null),
        label: 'MultiversX Web Wallet',
    },
};
const ProviderButton = /*@__PURE__*/ proxyCustomElement(class ProviderButton extends H {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
    }
    render() {
        const walletInfo = this.type ? providerButtonInfo[this.type] : null;
        if (!walletInfo) {
            return h(Fragment, null);
        }
        return h("unlock-button", { icon: walletInfo.icon, label: walletInfo.label });
    }
    static get style() { return ProviderButtonStyle0; }
}, [1, "provider-button", {
        "type": [1]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["provider-button", "unlock-button"];
    components.forEach(tagName => { switch (tagName) {
        case "provider-button":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, ProviderButton);
            }
            break;
        case "unlock-button":
            if (!customElements.get(tagName)) {
                defineCustomElement$1();
            }
            break;
    } });
}

export { ProviderButton as P, ProviderTypeEnum as a, defineCustomElement as d };

//# sourceMappingURL=p-614f4774.js.map