import { p as proxyCustomElement, H, h, f as forceUpdate } from './p-8a2c7dab.js';
import { E as EventBus } from './p-9d530225.js';
import { s as state, r as resetState } from './p-3c8ddf78.js';
import { d as defineCustomElement$3 } from './p-c7172a55.js';
import { d as defineCustomElement$2 } from './p-8324d312.js';

var SignEventsEnum;
(function (SignEventsEnum) {
    SignEventsEnum["SIGN_TRANSACTION"] = "SIGN_TRANSACTION";
    SignEventsEnum["NEXT_TRANSACTION"] = "NEXT_TRANSACTION";
    SignEventsEnum["PREV_TRANSACTION"] = "PREV_TRANSACTION";
    SignEventsEnum["CLOSE"] = "CLOSE";
    SignEventsEnum["DATA_UPDATE"] = "DATA_UPDATE";
})(SignEventsEnum || (SignEventsEnum = {}));

const signTransactionsModalCss = "*{margin:0;padding:0;box-sizing:border-box}.transaction-header-container{display:flex;flex-direction:column}.loading-spinner{display:flex;justify-content:center;align-items:center;min-height:350px}";
const SignTransactionsModalStyle0 = signTransactionsModalCss;

const signScreens = {
    FungibleESDT: 'token-component',
    SemiFungibleESDT: 'fungible-component',
    NonFungibleESDT: 'fungible-component',
    MetaESDT: 'token-component'
};
const SignTransactionsModal$1 = /*@__PURE__*/ proxyCustomElement(class SignTransactionsModal extends H {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.eventBus = new EventBus();
        this.data = {
            commonData: {
                egldLabel: '',
                feeLimit: '',
                feeInFiatLimit: '',
                transactionsCount: 0,
                currentIndex: 0
            },
            tokenTransaction: null,
            nftTransaction: null,
            sftTransaction: null
        };
    }
    async getEventBus() {
        return this.eventBus;
    }
    onDataChange(data) {
        for (const key in data) {
            if (Object.prototype.hasOwnProperty.call(state, key)) {
                state[key] = data[key];
            }
        }
        state.isWaitingForSignature = false;
        state.isLoading = false;
    }
    componentWillLoad() {
        state.onSign = () => {
            state.isWaitingForSignature = true;
            this.eventBus.publish(SignEventsEnum.SIGN_TRANSACTION);
        };
        state.onPrev = () => {
            this.eventBus.publish(SignEventsEnum.PREV_TRANSACTION);
        };
        state.onNext = () => {
            this.eventBus.publish(SignEventsEnum.NEXT_TRANSACTION);
        };
        state.onCancel = () => {
            this.eventBus.publish(SignEventsEnum.CLOSE);
        };
    }
    render() {
        const { commonData, isLoading } = state;
        const { tokenType, currentIndex, transactionsCount } = commonData;
        const SignScreen = signScreens[tokenType];
        return (h("generic-modal", { key: 'f8090b1c3757bba64778042a493aa7ece0304b6a', onClose: () => this.close(), modalTitle: "Sign transaction", modalSubtitle: `Transaction ${currentIndex + 1} of ${transactionsCount}`, body: isLoading ? (h("div", { class: "loading-spinner" }, h("generic-spinner", null))) : (h(SignScreen, null)) }));
    }
    close(props = { isUserClick: true }) {
        resetState();
        if (props.isUserClick) {
            this.eventBus.publish(SignEventsEnum.CLOSE);
        }
        if (this.hostElement && this.hostElement.parentNode) {
            this.hostElement.parentNode.removeChild(this.hostElement);
        }
    }
    dataUpdate(payload) {
        this.data = Object.assign({}, payload);
        forceUpdate(this);
    }
    componentDidLoad() {
        this.eventBus.subscribe(SignEventsEnum.DATA_UPDATE, this.dataUpdate.bind(this));
    }
    disconnectedCallback() {
        resetState();
        this.eventBus.unsubscribe(SignEventsEnum.DATA_UPDATE, this.dataUpdate.bind(this));
    }
    get hostElement() { return this; }
    static get watchers() { return {
        "data": ["onDataChange"]
    }; }
    static get style() { return SignTransactionsModalStyle0; }
}, [1, "sign-transactions-modal", {
        "data": [16],
        "getEventBus": [64]
    }, undefined, {
        "data": ["onDataChange"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["sign-transactions-modal", "generic-modal", "generic-spinner"];
    components.forEach(tagName => { switch (tagName) {
        case "sign-transactions-modal":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, SignTransactionsModal$1);
            }
            break;
        case "generic-modal":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "generic-spinner":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}

const SignTransactionsModal = SignTransactionsModal$1;
const defineCustomElement = defineCustomElement$1;

export { SignTransactionsModal, defineCustomElement };

//# sourceMappingURL=sign-transactions-modal.js.map