import { r as registerInstance, c as createEvent, h } from './index-755f1da5.js';
import { a as faTimes } from './index-221feb2b.js';
import { g as getIconHtmlFromIconDefinition } from './getIconHtmlFromIconDefinition-2377fd50.js';
import { c as classNames } from './index-097075ad.js';
import { D as DataTestIdsEnum } from './dataTestIds.enum-55de9911.js';
import { g as getIconHtmlFromIconName } from './getIconHtmlFromIconName-98725b36.js';

const customToastCss = ".toast-wrapper{border-radius:0.25rem;box-shadow:0 0.25rem 0.75rem rgba(0, 0, 0, 0.1);margin-bottom:0.7rem;padding:0.5rem;background-color:#fff;position:relative}.icon-close{position:absolute;right:16px;top:16px;cursor:pointer;font-size:1.5rem;font-weight:700;line-height:1;color:#000;text-shadow:0 1px 0 #fff;opacity:0.5;padding:0;background-color:rgba(0, 0, 0, 0);border:0;display:flex;align-items:center;margin:0 0.5rem;width:12px}.toast-body{display:flex;align-items:center;flex:1;font-size:16px}";
const CustomToastStyle0 = customToastCss;

const CustomToast = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.handleDeleteToast = createEvent(this, "handleDeleteToast", 7);
    }
    render() {
        const customToast = (h("div", { key: '2142330869ed08b7cc56e94ac3c78de3b25c651b', class: "toast-wrapper" }, h("button", { key: 'fc7d8910d259a35e1722f39463086dffdbdd7be5', onClick: () => this.handleDeleteToast.emit(), type: "button", class: "icon-close", innerHTML: getIconHtmlFromIconDefinition(faTimes) }), h("div", { key: 'f000b96be24746241d25c2de2749b95eeeafd3ca', class: "toast-body", ref: container => this.initializeToast(container) })));
        return customToast;
    }
    initializeToast(container) {
        if (!container || container.hasChildNodes()) {
            return;
        }
        const customElement = this.toast.instantiateToastElement();
        if (!customElement) {
            return;
        }
        container.appendChild(customElement);
    }
};
CustomToast.style = CustomToastStyle0;

const simpleToastCss = ".content {\n  display: flex;\n  align-items: center;\n}\n\n.content-left {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  flex-direction: column;\n  padding-left: 0.5rem;\n  padding-right: 0.75rem;\n\n  &.no-icon {\n    display: none;\n  }\n}\n\n.content-icon {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  width: 3rem;\n  height: 3rem;\n  border-radius: 50%;\n\n  svg {\n    height: auto;\n    width: 20px;\n\n    path {\n      fill: white;\n    }\n  }\n}\n\n.icon-close {\n  position: absolute;\n  right: 16px;\n  top: 16px;\n  font-size: 1.5rem;\n  font-weight: 700;\n  line-height: 1;\n  color: #000;\n  text-shadow: 0 1px 0 #fff;\n  opacity: 0.5;\n  padding: 0;\n  background-color: rgba(0, 0, 0, 0);\n  border: 0;\n  display: flex;\n  align-items: center;\n  margin: 0 0.5rem;\n  width: 12px;\n}\n\n.content-right {\n  display: flex;\n  flex-direction: column;\n  justify-content: center;\n  width: 100%;\n}\n\n.content-heading {\n  display: flex;\n  justify-content: space-between;\n  align-items: center;\n  margin-bottom: 0.25rem;\n\n  h5 {\n    margin: 0;\n    margin-bottom: 0.5rem;\n    font-weight: 500;\n    line-height: 1.2;\n    font-size: 1.25rem;\n  }\n}\n\n.content-message {\n  margin-top: 0.25rem;\n  font-size: 1rem;\n  &.no-margin {\n    margin-top: 0rem;\n  }\n}\n\n.subtitle {\n  font-size: 0.9rem;\n  font-weight: 500;\n  color: #6c757d;\n}\n\n.success {\n  background-color: #5cb85c;\n}\n\n.warning {\n  background-color: #ffc107;\n}\n\n.danger {\n  background-color: #d9534f;\n}\n";
const SimpleToastStyle0 = simpleToastCss;

const SimpleToast = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.handleDeleteToast = createEvent(this, "handleDeleteToast", 7);
    }
    render() {
        const { icon, iconClassName, title, message, subtitle } = this.toast;
        let iconHtml = null;
        if (typeof icon === 'string') {
            iconHtml = getIconHtmlFromIconName(icon);
        }
        if (icon instanceof HTMLElement) {
            iconHtml = icon.outerHTML;
        }
        return (h("transaction-toast-wrapper", { key: 'aa80c314d2460906d2858a64856925ccd11b95f3', wrapperId: `toast-${this.toast.toastId}` }, h("div", { key: 'f3b7e154ad973a9b42563a0a0b8d2d167d81d326', class: "content", "data-testid": DataTestIdsEnum.transactionToastContent }, iconHtml && (h("div", { key: '80601c266cc719a438a6bb26a93cebe736f40b1a', class: classNames('content-left', { 'no-icon': !iconHtml }) }, h("div", { key: '679093eaa22d59de78a44101aba4ac6059b17039', class: classNames('content-icon', iconClassName), innerHTML: iconHtml }))), h("div", { key: '8af0efeeabd8cfc965b6be0c27278551442a4130', class: "content-right" }, title && (h("div", { key: 'd0421a98d1c8eff2f8dc31663f2e9ca2235d3ab4', class: "content-heading" }, h("h5", { key: 'b624b26d2e52c9bed7ff21f0852cb9354ec14d90', class: "content-heading-title", "data-testid": DataTestIdsEnum.transactionToastTitle }, title))), h("button", { key: '11de9b386d1e6003120677167498db715fe7c0b0', onClick: () => this.handleDeleteToast.emit(), type: "button", class: "icon-close", innerHTML: getIconHtmlFromIconDefinition(faTimes) }), subtitle && h("div", { key: '8941758ed269595cd05e60aadf9bbbd093cfc09b', class: "subtitle" }, subtitle), message && h("div", { key: 'dadeaaaa591540e4a7acac024906398fab5179e7', class: classNames('content-message', { 'no-margin': !title && !subtitle }) }, message)))));
    }
};
SimpleToast.style = SimpleToastStyle0;

export { CustomToast as custom_toast, SimpleToast as simple_toast };

//# sourceMappingURL=custom-toast_2.entry.js.map