import { r as registerInstance, h, f as forceUpdate, a as getElement } from './index-755f1da5.js';
import { D as DataTestIdsEnum } from './dataTestIds.enum-55de9911.js';
import { a as LedgerConnectEventsEnum, L as LedgerConnectBase } from './LedgerConnectBase-5b3f65a4.js';
import './EventBus-56ba7d6d.js';

const LedgerConnectModal = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.data = {
            accountScreenData: null,
            confirmScreenData: null,
            connectScreenData: {},
        };
        this.selectedIndex = 0;
        this.getModalProps = () => {
            const { accountScreenData, confirmScreenData, connectScreenData } = this.data;
            if (accountScreenData) {
                return {
                    modalTitle: h("div", { "data-testid": `${DataTestIdsEnum.addressTableContainer}Title` }, "Access your wallet"),
                    modalSubtitle: h("div", { "data-testid": `${DataTestIdsEnum.addressTableContainer}SubTitle` }, "Choose the wallet you want to access"),
                    body: (h("ledger-account-screen", { accountScreenData: accountScreenData, selectedIndex: this.selectedIndex, onSelectAccount: (event) => this.selectAccount(event.detail), onAccessWallet: () => this.accessWallet(), onPrevPage: () => this.prevPage(), onNextPage: () => this.nextPage() })),
                };
            }
            if (confirmScreenData) {
                return {
                    modalTitle: 'Confirm',
                    modalSubtitle: 'Confirm Ledger Address',
                    body: h("ledger-confirm-screen", { confirmScreenData: confirmScreenData }),
                };
            }
            return {
                modalTitle: 'Connect Ledger',
                modalSubtitle: 'Unlock your device & open the MultiversX App',
                body: h("ledger-connect-screen", { connectScreenData: connectScreenData, onConnect: () => this.ledgerConnectBase.eventBus.publish(LedgerConnectEventsEnum.CONNECT_DEVICE) }),
            };
        };
    }
    componentWillLoad() {
        this.ledgerConnectBase = new LedgerConnectBase(this.data);
    }
    async getEventBus() {
        return this.ledgerConnectBase.getEventBus();
    }
    render() {
        const modalProps = this.getModalProps();
        return h("generic-modal", Object.assign({ key: 'd01d92ca0fcc5501f254543498ab565ce2007361' }, modalProps, { onClose: () => this.close() }));
    }
    accessWallet() {
        this.ledgerConnectBase.accessWallet();
    }
    selectAccount(index) {
        this.ledgerConnectBase.selectAccount(index);
        // this is needed for the UI to be reactive
        this.selectedIndex = this.ledgerConnectBase.selectedIndex;
    }
    async nextPage() {
        this.ledgerConnectBase.nextPage();
    }
    async prevPage() {
        this.ledgerConnectBase.prevPage();
    }
    close(props = { isUserClick: true }) {
        var _a;
        if (props.isUserClick) {
            this.ledgerConnectBase.eventBus.publish(LedgerConnectEventsEnum.CLOSE);
        }
        if ((_a = this.hostElement) === null || _a === void 0 ? void 0 : _a.parentNode) {
            this.hostElement.parentNode.removeChild(this.hostElement);
        }
    }
    componentDidLoad() {
        this.ledgerConnectBase.subscribeEventBus({
            closeFn: () => this.close({ isUserClick: false }),
            forceUpdateFn: () => {
                // this is needed for the UI to be reactive
                this.data = this.ledgerConnectBase.data;
                forceUpdate(this);
            },
        });
    }
    disconnectedCallback() {
        this.ledgerConnectBase.unsubscribeEventBus({
            closeFn: () => this.close({ isUserClick: false }),
            forceUpdateFn: () => {
                // this is needed for the UI to be reactive
                this.data = this.ledgerConnectBase.data;
                forceUpdate(this);
            },
        });
    }
    get hostElement() { return getElement(this); }
};

export { LedgerConnectModal as ledger_connect_modal };

//# sourceMappingURL=ledger-connect-modal.entry.js.map