import { r as registerInstance, h, f as forceUpdate, a as getElement } from './index-755f1da5.js';
import { D as DataTestIdsEnum } from './dataTestIds.enum-55de9911.js';
import { E as EventBus } from './EventBus-56ba7d6d.js';

// types here need to be synced with the types in sdk-dapp-core pendingTransactions.types.ts
var PendingTransactionsEventsEnum;
(function (PendingTransactionsEventsEnum) {
    PendingTransactionsEventsEnum["CLOSE"] = "CLOSE";
    PendingTransactionsEventsEnum["DATA_UPDATE"] = "DATA_UPDATE";
})(PendingTransactionsEventsEnum || (PendingTransactionsEventsEnum = {}));

const pendingTransactionsModalCss = ".modal-body{display:flex;justify-content:center;align-items:center;padding:16px}.close-button{cursor:pointer;color:#ffff;background-color:#343a40;border-color:#343a40;border-radius:0.25rem;padding:0.375rem 0.75rem;border:1px solid rgba(0, 0, 0, 0)}";
const PendingTransactionsModalStyle0 = pendingTransactionsModalCss;

const PendingTransactionstModal = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.eventBus = new EventBus();
        this.data = {
            isPending: false,
            title: '',
            subtitle: '',
        };
    }
    async getEventBus() {
        return this.eventBus;
    }
    render() {
        return (h("generic-modal", { key: '4580f5ba73b46ea9335239d0cc2274b8a60f8f8b', modalTitle: h("div", { "data-testid": DataTestIdsEnum.pendingTransactionsTitle }, this.data.title), modalSubtitle: h("div", { "data-testid": DataTestIdsEnum.pendingTransactionsSubtitle }, this.data.subtitle), onClose: () => this.close(), body: h("div", { class: "modal-body" }, h("button", { class: "close-button", onClick: () => this.close() }, "Close")) }));
    }
    close(props = { isUserClick: true }) {
        if (props.isUserClick) {
            this.eventBus.publish(PendingTransactionsEventsEnum.CLOSE);
        }
        if (this.hostElement && this.hostElement.parentNode) {
            this.hostElement.parentNode.removeChild(this.hostElement);
        }
    }
    dataUpdate(payload) {
        if (payload.shouldClose) {
            return this.close({ isUserClick: false });
        }
        this.data = Object.assign({}, payload);
        forceUpdate(this);
    }
    componentDidLoad() {
        this.eventBus.subscribe(PendingTransactionsEventsEnum.DATA_UPDATE, this.dataUpdate.bind(this));
    }
    disconnectedCallback() {
        this.eventBus.unsubscribe(PendingTransactionsEventsEnum.DATA_UPDATE, this.dataUpdate.bind(this));
    }
    get hostElement() { return getElement(this); }
};
PendingTransactionstModal.style = PendingTransactionsModalStyle0;

export { PendingTransactionstModal as pending_transactions_modal };

//# sourceMappingURL=pending-transactions-modal.entry.js.map