import { h, F as Fragment, r as registerInstance, c as createEvent } from './index-755f1da5.js';
import { P as ProviderTypeEnum } from './provider.types-c9b223f4.js';
import { a as faTimes } from './index-221feb2b.js';

const providerButtonCss = ":host{display:block;width:100%}.connect-button{display:flex;align-items:center;padding:12px;border-radius:12px;background:white;box-shadow:0 2px 6px rgba(0, 0, 0, 0.05);cursor:pointer;transition:background 0.3s ease}.connect-button:hover{background:#fafafa}.connect-icon{width:40px;height:40px;border-radius:8px;overflow:hidden;display:flex;align-items:center;justify-content:center;border:1px solid #ebe5df}.connect-icon img{width:100%;height:100%;object-fit:cover}.connect-label{flex:1;margin-left:12px;font-size:16px;font-weight:500}";
const ProviderButtonStyle0 = providerButtonCss;

const providerButtonInfo = {
    [ProviderTypeEnum.extension]: {
        icon: h(Fragment, null),
        label: 'MultiversX Wallet Extension',
    },
    [ProviderTypeEnum.metamask]: {
        icon: h(Fragment, null),
        label: 'Metamask Snap',
    },
    [ProviderTypeEnum.passkey]: {
        icon: h(Fragment, null),
        label: 'Passkey',
    },
    [ProviderTypeEnum.walletConnect]: {
        icon: h(Fragment, null),
        label: 'xPortal Wallet',
    },
    [ProviderTypeEnum.ledger]: {
        icon: h(Fragment, null),
        label: 'Ledger',
    },
    [ProviderTypeEnum.crossWindow]: {
        icon: h(Fragment, null),
        label: 'MultiversX Web Wallet',
    },
};
const ProviderButton = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    render() {
        const walletInfo = this.type ? providerButtonInfo[this.type] : null;
        if (!walletInfo) {
            return h(Fragment, null);
        }
        return h("unlock-button", { icon: walletInfo.icon, label: walletInfo.label });
    }
};
ProviderButton.style = ProviderButtonStyle0;

const unlockHeaderCss = ".header{display:flex;align-items:center;justify-content:space-between;padding:12px 16px;border-radius:8px;font-size:16px;font-weight:bold;color:#333;text-transform:capitalize}.icon-button{background:none;border:none;cursor:pointer;display:flex;align-items:center;padding:8px}.icon-button .icon{font-size:20px;color:#333;cursor:pointer}.title{flex:1;text-align:left}";
const UnlockHeaderStyle0 = unlockHeaderCss;

const UnlockHeader = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.back = createEvent(this, "back", 7);
        this.close = createEvent(this, "close", 7);
        this.closeIcon = faTimes;
        this.handleBack = () => {
            this.back.emit();
        };
        this.handleClose = () => {
            this.close.emit();
        };
    }
    render() {
        return (h("div", { key: '6011ca2eafdbf26b5066251b3bab487e693168a6', class: 'header' }, this.backIcon && (h("button", { key: 'db229733cba8c1a9f981b19552b2bb0f90103b6e', class: "icon-button", onClick: this.handleBack }, h("fa-icon", { key: 'fd6c0418eaeb6fc327bfd74040f76e8ef4a8b2c9', icon: this.backIcon }))), h("span", { key: 'c09b4ee34c9b4c453ae4ae39a06736bb5cbbe79a', class: "title" }, this.text), h("button", { key: 'a0e0a3ea287ad8b273541a18ca7836f68f4972df', class: "icon-button", onClick: this.handleClose }, h("fa-icon", { key: '6300e01cc88bf54b5d5c4668b77fe602a3aed882', icon: this.closeIcon }))));
    }
};
UnlockHeader.style = UnlockHeaderStyle0;

export { ProviderButton as provider_button, UnlockHeader as unlock_header };

//# sourceMappingURL=provider-button_2.entry.js.map