import { r as registerInstance, c as createEvent, h, F as Fragment } from './index-755f1da5.js';
import { a as faTimes, c as faChevronUp, d as faChevronDown } from './index-221feb2b.js';
import { c as classNames } from './index-097075ad.js';
import { D as DataTestIdsEnum } from './dataTestIds.enum-55de9911.js';
import { g as getIconHtmlFromIconDefinition } from './getIconHtmlFromIconDefinition-2377fd50.js';
import { g as getIconHtmlFromIconName } from './getIconHtmlFromIconName-98725b36.js';

const transactionToastContentCss = ".content {\n  display: flex;\n  align-items: center;\n}\n.content-left {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  flex-direction: column;\n  padding-left: 0.5rem;\n  padding-right: 0.75rem;\n}\n.success {\n  background-color: #5cb85c;\n}\n.warning {\n  background-color: #ffc107;\n}\n.danger {\n  background-color: #d9534f;\n}\n.content-icon {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  width: 3rem;\n  height: 3rem;\n  border-radius: 50%;\n  svg {\n    height: auto;\n    width: 20px;\n\n    path {\n      fill: white;\n    }\n  }\n}\n\n.icon-close {\n  cursor: pointer;\n  float: right;\n  font-size: 1.5rem;\n  font-weight: 700;\n  line-height: 1;\n  color: #000;\n  text-shadow: 0 1px 0 #fff;\n  opacity: 0.5;\n  padding: 0;\n  background-color: rgba(0, 0, 0, 0);\n  border: 0;\n  display: flex;\n  align-items: center;\n  margin: 0 0.5rem;\n  width: 12px;\n}\n\n.content-right {\n  display: block;\n  overflow: hidden;\n  width: 100%;\n}\n\n.content-heading {\n  display: flex;\n  justify-content: space-between;\n  margin-bottom: 0.25rem;\n}\n\n.content-heading-title {\n  margin: 0;\n  margin-bottom: 0.5rem;\n  font-weight: 500;\n  line-height: 1.2;\n  font-size: 1.25rem;\n}\n";
const TransactionToastContentStyle0 = transactionToastContentCss;

const TransactionToastContent = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.deleteToast = createEvent(this, "deleteToast", 7);
    }
    handleDeleteToast() {
        this.deleteToast.emit();
    }
    render() {
        const { icon, iconClassName, title, hasCloseButton } = this.toastDataState;
        let iconHtml = null;
        if (typeof icon === 'string') {
            iconHtml = getIconHtmlFromIconName(icon);
        }
        if (icon instanceof HTMLElement) {
            iconHtml = icon.outerHTML;
        }
        return (h("div", { key: '90320848fe10eb6fc9ed8be5c74ea091643f7eb7', class: "content", "data-testid": DataTestIdsEnum.transactionToastContent }, h("div", { key: '78a974839143d81551d076d6fc2b58979ac1e801', class: "content-left" }, h("div", { key: 'ff85b0fe208e13f2e493d0acde312d05af5373e0', class: classNames('content-icon', iconClassName), innerHTML: iconHtml })), h("div", { key: 'a1203080aab982c00d572fea4bc9a031bc01f769', class: "content-right" }, h("div", { key: '97ad902c23134de023cd31254a4b45e2f94e1928', class: "content-heading" }, h("h5", { key: 'dfb744d224737ff286d646c09a1548a4708c0ccf', class: "content-heading-title", "data-testid": DataTestIdsEnum.transactionToastTitle }, title), hasCloseButton && h("button", { key: '6b2ce03bfd7ab7ee57d0e7a9e2d8ecebd3ce4f13', onClick: this.handleDeleteToast.bind(this), type: "button", class: "icon-close", innerHTML: getIconHtmlFromIconDefinition(faTimes) })), h("div", { key: '7e3c10e52748e4b5815aaf0f8e4710c9876c1b5b', class: "content-heading-title" }, h("transaction-toast-details", { key: 'b5d327160ea504bc91fe474dc5ac645dcfbacb80', transactions: this.transactions, processedTransactionsStatus: this.processedTransactionsStatus })))));
    }
};
TransactionToastContent.style = TransactionToastContentStyle0;

const transactionToastDetailsCss = ".status-title{font-size:0.875rem;margin:0.25rem 0 0.5rem;line-height:1.5;display:flex;align-items:center;cursor:pointer}.toggle-icon{margin-right:0.5rem;font-size:0.75rem;flex-shrink:0}.transaction-details-list{margin-bottom:0.5rem}.view-all-container{display:flex;justify-content:center;margin-top:0.5rem}.show-more-button{font-size:0.875rem;color:var(--mx-dapp-core-color-primary, #2044F5);text-decoration:none;cursor:pointer;background:none;border:none;padding:0;font-family:inherit}.show-more-button:hover{text-decoration:underline}";
const TransactionToastDetailsStyle0 = transactionToastDetailsCss;

const TransactionDetails = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.maxShownTransactions = 5;
        this.isExpanded = false;
        this.showAllTransactions = false;
    }
    toggleExpand() {
        this.isExpanded = !this.isExpanded;
        // Reset showAllTransactions when collapsing
        if (!this.isExpanded) {
            this.showAllTransactions = false;
        }
    }
    showMoreTransactions() {
        this.showAllTransactions = true;
    }
    render() {
        if (this.transactions == null) {
            return null;
        }
        const hasMoreTransactionsToShow = this.transactions.length > this.maxShownTransactions;
        const hiddenTransactionsCount = this.transactions.length - this.maxShownTransactions;
        const visibleTransactions = this.showAllTransactions ? this.transactions : this.transactions.slice(0, this.maxShownTransactions);
        return (h(Fragment, null, h("div", { class: "status-title", onClick: this.toggleExpand.bind(this) }, h("fa-icon", { icon: this.isExpanded ? faChevronUp : faChevronDown, class: "toggle-icon" }), this.processedTransactionsStatus), this.isExpanded && (h("div", { class: "transaction-details-list" }, visibleTransactions.map(({ hash, status, link }) => (h("transaction-toast-details-body", { transactionClass: this.transactionClass, hash: hash, status: status, link: link, key: hash }))), hasMoreTransactionsToShow && !this.showAllTransactions && (h("div", { class: "view-all-container" }, h("button", { type: "button", class: "show-more-button", onClick: this.showMoreTransactions.bind(this) }, "Show ", hiddenTransactionsCount, " more")))))));
    }
};
TransactionDetails.style = TransactionToastDetailsStyle0;

const transactionToastProgressCss = "@keyframes progressiveFixedWidthExpansion{from{width:min(var(--start-width, 0%), 80%)}to{width:80%}}@keyframes progressiveInfiniteWidthExpansion{from{width:min(var(--start-width, 0%), 100%)}to{width:100%}}@keyframes quickWidthExpansion{from{width:0%}to{width:100%}}.transaction-toast-progress{position:relative}.transaction-toast-bar-wrapper{transition:opacity 250ms ease-in;background-color:lightgray;position:absolute;pointer-events:none;left:0;top:0;opacity:25%;bottom:0;right:0;display:flex;overflow:hidden;border-radius:0.25rem;flex-direction:row-reverse}.transaction-toast-bar{height:100%;right:0;top:0;bottom:0}.transaction-toast-bar.fixed{width:min(var(--start-width, 0%), 50%);background-color:white;animation-name:progressiveFixedWidthExpansion;animation-duration:var(--animation-duration, 6s);animation-timing-function:cubic-bezier(0.5, 0.95, 0, 0.35);animation-fill-mode:forwards}.transaction-toast-bar.infinite{width:20%;display:flex;flex-direction:row-reverse}.transaction-toast-bar.infinite .transaction-toast-bar-line{width:0%;background-color:white;animation-name:progressiveInfiniteWidthExpansion;animation-duration:var(--animation-duration, 60s);animation-timing-function:cubic-bezier(0.1, 0.95, 0.25, 0.75);animation-fill-mode:forwards;animation-delay:var(--animation-delay, 6s);height:100%;position:relative}.transaction-toast-bar.infinite .transaction-toast-bar-line:before{position:absolute;background-color:white;content:'';width:calc(4px / 2);right:-1px;top:0;bottom:0}.transaction-toast-bar.fill{width:0%;position:absolute;background-color:white}.transaction-toast-bar.fill.animate{animation:quickWidthExpansion 250ms linear forwards}.transaction-toast-bar-content{z-index:1;position:relative}";
const TransactionToastProgressStyle0 = transactionToastProgressCss;

const DEFAULT_INFINITE_ANIMATION_DURATION = 30;
const ToastProgress = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.currentTimestamp = Date.now() / 1000;
        this.hasTimeElapsed = false;
        this.expectedTransactionDuration = 0;
        this.secondsPassedSinceStart = 0;
        this.shouldShowProgressBar = false;
        this.percentagePassedSinceStart = 0;
        this.shouldQuickFill = false;
        this.infiniteProgressDelay = 0;
        this.infinitePercentagePassedSinceStart = 0;
        this.infinitePercentageAnimationDuration = DEFAULT_INFINITE_ANIMATION_DURATION + (this.endTime - this.startTime) * 2;
    }
    componentWillLoad() {
        this.updateProgress();
    }
    handleTimeChange() {
        this.updateProgress();
    }
    updateProgress() {
        this.shouldShowProgressBar = Boolean(this.endTime) && Boolean(this.startTime);
        if (!this.shouldShowProgressBar) {
            this.shouldQuickFill = true;
            this.timeElapsedTimeoutReference = setTimeout(() => (this.hasTimeElapsed = true), 500);
            return;
        }
        this.currentTimestamp = Date.now() / 1000;
        this.expectedTransactionDuration = this.endTime - this.startTime;
        this.secondsPassedSinceStart = this.currentTimestamp - this.startTime;
        this.percentagePassedSinceStart = this.expectedTransactionDuration > 0 ? (this.secondsPassedSinceStart / this.expectedTransactionDuration) * 100 : 0;
        this.infiniteProgressDelay = Math.max(0, this.expectedTransactionDuration - this.secondsPassedSinceStart);
        this.infinitePercentagePassedSinceStart = (this.secondsPassedSinceStart / (this.expectedTransactionDuration + this.infinitePercentageAnimationDuration)) * 100;
    }
    disconnectedCallback() {
        if (this.timeElapsedTimeoutReference) {
            clearTimeout(this.timeElapsedTimeoutReference);
        }
    }
    render() {
        return (h(Fragment, { key: '17d20c3cba450c3246390ec7e4bacac31c14faae' }, h("div", { key: '186afef6a363bd4442423433ef3657a549d8f357', class: "transaction-toast-bar-wrapper", style: { opacity: this.hasTimeElapsed ? '0' : '1' } }, h("div", { key: 'f7839f7d30162bbe6bff080a7161f84d68e5765a', class: "transaction-toast-bar fixed", style: {
                '--animation-duration': `${this.expectedTransactionDuration}s`,
                '--start-width': `${this.percentagePassedSinceStart}%`,
            } }), h("div", { key: 'b3225a264857691d58bfea7f1802dba0f21e629d', class: "transaction-toast-bar infinite" }, h("div", { key: 'd971423bb5c54f62603709cc85d237b9d3386dd3', class: "transaction-toast-bar-line", style: {
                '--start-width': `${this.infinitePercentagePassedSinceStart}%`,
                '--animation-duration': `${this.infinitePercentageAnimationDuration}s`,
                '--animation-delay': `${this.infiniteProgressDelay}s`,
            } })), h("div", { key: 'dd33a3ec7ae7bea03a3d1826d6e4fb9074b8fff7', class: classNames('transaction-toast-bar fill', {
                animate: this.shouldQuickFill,
            }) })), h("div", { key: '0dfa097e7d6439bfaaef2e0893e2755453b1420c', class: "transaction-toast-bar-content" }, h("slot", { key: '63b18f4ce255a84011421f6b76293b3cc459e19f' }))));
    }
    static get watchers() { return {
        "startTime": ["handleTimeChange"],
        "endTime": ["handleTimeChange"]
    }; }
};
ToastProgress.style = TransactionToastProgressStyle0;

export { TransactionToastContent as transaction_toast_content, TransactionDetails as transaction_toast_details, ToastProgress as transaction_toast_progress };

//# sourceMappingURL=transaction-toast-content_3.entry.js.map