import { r as registerInstance, c as createEvent, h } from './index-755f1da5.js';
import { f as faArrowLeft } from './index-221feb2b.js';
import { P as ProviderTypeEnum } from './provider.types-c9b223f4.js';

const unlockPanelCss = ":host{display:block}.overlay{position:fixed;top:0;left:0;width:100%;height:100%;background:rgba(0, 0, 0, 0.5);display:flex;justify-content:flex-end;align-items:center;opacity:0;pointer-events:none;transition:opacity 0.3s ease-in-out}.overlay.visible{opacity:1;pointer-events:auto}.panel{border-top-left-radius:12px;border-bottom-left-radius:12px;width:100%;max-width:340px;height:100%;background:#f5f1ec;box-shadow:-2px 0 10px rgba(0, 0, 0, 0.3);transform:translateX(100%);transition:transform 0.3s ease-in-out}.body{display:flex;flex-direction:column;gap:0.2rem;padding:1rem}.overlay.visible .panel{transform:translateX(0)}";
const UnlockPanelStyle0 = unlockPanelCss;

const UnlockPanel = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.close = createEvent(this, "close", 7);
        this.login = createEvent(this, "login", 7);
        this.open = false;
        this.allowedProviders = Object.values(ProviderTypeEnum);
        this.isVisible = false; // Controls DOM presence
        this.shouldAnimate = false; // Ensures animation plays on open
        this.isLoggingIn = false;
        this.selectedMethod = null;
        this.anchor = null;
        this.observer = null;
        this.closeTimeout = null;
        this.handleClose = (event) => {
            if (event.target === event.currentTarget) {
                this.close.emit();
            }
        };
        this.handleLogin = (provider) => {
            this.login.emit({ provider, anchor: this.anchor });
            this.selectedMethod = provider;
        };
        this.resetLoginState = () => {
            this.isLoggingIn = false;
            this.selectedMethod = null;
            if (!this.anchor) {
                return;
            }
            while (this.anchor.firstChild) {
                this.anchor.removeChild(this.anchor.firstChild);
            }
        };
    }
    handleOpenChange(newValue) {
        if (newValue) {
            if (this.closeTimeout) {
                clearTimeout(this.closeTimeout);
            }
            this.isVisible = true; // Ensure component is in DOM
            // Delay animation to allow rendering first
            return requestAnimationFrame(() => {
                this.shouldAnimate = true;
            });
        }
        this.shouldAnimate = false;
        this.closeTimeout = setTimeout(() => {
            this.isVisible = false;
            this.resetLoginState();
        }, 300); // Delay unmounting after animation
    }
    disconnectedCallback() {
        if (this.closeTimeout) {
            clearTimeout(this.closeTimeout);
        }
        if (this.observer) {
            this.observer.disconnect();
        }
    }
    observeContainer(element) {
        if (!element) {
            return;
        }
        this.anchor = element;
        if (this.observer) {
            this.observer.disconnect();
        }
        this.observer = new MutationObserver(() => {
            this.isLoggingIn = element.childElementCount > 0;
        });
        this.observer.observe(element, { childList: true, subtree: true });
    }
    render() {
        if (!this.isVisible) {
            return null;
        }
        return (h("div", { class: {
                overlay: true,
                visible: this.shouldAnimate,
                hidden: !this.shouldAnimate,
            }, onClick: this.handleClose, tabindex: "-1" }, h("div", { class: "panel" }, h("unlock-header", { text: this.isLoggingIn ? `${this.selectedMethod} connect` : 'Connect your wallet', backIcon: this.isLoggingIn ? faArrowLeft : null, onBack: this.resetLoginState, onClose: () => this.close.emit() }), h("div", { id: "anchor", ref: element => this.observeContainer(element) }), !this.isLoggingIn && (h("div", { class: "body" }, this.allowedProviders.map(method => (h("provider-button", { type: method, onClick: () => this.handleLogin(method) }))), h("slot", null))))));
    }
    static get watchers() { return {
        "open": ["handleOpenChange"]
    }; }
};
UnlockPanel.style = UnlockPanelStyle0;

export { UnlockPanel as unlock_panel };

//# sourceMappingURL=unlock-panel.entry.js.map